@@ -28,15 +28,15 @@
 #include <sys/ioctl.h>
 #include <netpacket/packet.h> /* For sockaddr_ll */
 #if defined(__clang__)
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdocumentation"
+#  pragma clang diagnostic push
+#  pragma clang diagnostic ignored "-Wdocumentation"
 #endif
-#include <linux/filter.h>     /* For BPF filtering */
+#include <linux/filter.h> /* For BPF filtering */
 #include <linux/sockios.h>
 #include <linux/if_ether.h>
 #include <linux/ethtool.h>
 #if defined(__clang__)
-#pragma clang diagnostic pop
+#  pragma clang diagnostic pop
 #endif
 
 /* Defined in linux/pkt_sched.h */
@@ -56,48 +56,38 @@ priv_open(char *file)
 	must_write(PRIV_UNPRIVILEGED, file, len);
 	priv_wait();
 	must_read(PRIV_UNPRIVILEGED, &rc, sizeof(int));
-	if (rc == -1)
-		return rc;
+	if (rc == -1) return rc;
 	return receive_fd(PRIV_UNPRIVILEGED);
 }
 
 void
 asroot_open()
 {
-	const char* authorized[] = {
-		PROCFS_SYS_NET "ipv4/ip_forward",
+	const char *authorized[] = { PROCFS_SYS_NET "ipv4/ip_forward",
 		PROCFS_SYS_NET "ipv6/conf/all/forwarding",
-		"/proc/net/bonding/[^.][^/]*",
-		"/proc/self/net/bonding/[^.][^/]*",
+		"/proc/net/bonding/[^.][^/]*", "/proc/self/net/bonding/[^.][^/]*",
 #ifdef ENABLE_OLDIES
 		SYSFS_CLASS_NET "[^.][^/]*/brforward",
 		SYSFS_CLASS_NET "[^.][^/]*/brport",
 		SYSFS_CLASS_NET "[^.][^/]*/brif/[^.][^/]*/port_no",
 #endif
-		SYSFS_CLASS_DMI "product_version",
-		SYSFS_CLASS_DMI "product_serial",
-		SYSFS_CLASS_DMI "product_name",
-		SYSFS_CLASS_DMI "bios_version",
-		SYSFS_CLASS_DMI "sys_vendor",
-		SYSFS_CLASS_DMI "chassis_asset_tag",
-		NULL
-	};
+		SYSFS_CLASS_DMI "product_version", SYSFS_CLASS_DMI "product_serial",
+		SYSFS_CLASS_DMI "product_name", SYSFS_CLASS_DMI "bios_version",
+		SYSFS_CLASS_DMI "sys_vendor", SYSFS_CLASS_DMI "chassis_asset_tag",
+		NULL };
 	const char **f;
 	char *file;
 	int fd, len, rc;
 	regex_t preg;
 
 	must_read(PRIV_PRIVILEGED, &len, sizeof(len));
-	if (len < 0 || len > PATH_MAX)
-		fatalx("privsep", "too large value requested");
-	if ((file = (char *)malloc(len + 1)) == NULL)
-		fatal("privsep", NULL);
+	if (len < 0 || len > PATH_MAX) fatalx("privsep", "too large value requested");
+	if ((file = (char *)malloc(len + 1)) == NULL) fatal("privsep", NULL);
 	must_read(PRIV_PRIVILEGED, file, len);
 	file[len] = '\0';
 
-	for (f=authorized; *f != NULL; f++) {
-		if (regcomp(&preg, *f, REG_NOSUB) != 0)
-			/* Should not happen */
+	for (f = authorized; *f != NULL; f++) {
+		if (regcomp(&preg, *f, REG_NOSUB) != 0) /* Should not happen */
 			fatal("privsep", "unable to compile a regex");
 		if (regexec(&preg, file, 0, NULL, 0) == 0) {
 			regfree(&preg);
@@ -133,12 +123,8 @@ asroot_iface_init_quirks(int ifindex, char *name)
 	int fd = -1;
 
 	/* Check driver. */
-	struct ethtool_drvinfo ethc = {
-		.cmd = ETHTOOL_GDRVINFO
-	};
-	struct ifreq ifr = {
-		.ifr_data = (caddr_t)&ethc
-	};
+	struct ethtool_drvinfo ethc = { .cmd = ETHTOOL_GDRVINFO };
+	struct ifreq ifr = { .ifr_data = (caddr_t)&ethc };
 	if ((s = socket(AF_INET, SOCK_DGRAM, 0)) == -1) {
 		log_warn("privsep", "unable to open a socket");
 		goto end;
@@ -150,8 +136,7 @@ asroot_iface_init_quirks(int ifindex, char *name)
 		goto end;
 	}
 	log_info("interfaces",
-	    "i40e driver detected for %s, disabling LLDP in firmware",
-	    name);
+	    "i40e driver detected for %s, disabling LLDP in firmware", name);
 
 	/* We assume debugfs is mounted. Otherwise, we would need to check if it
 	 * is mounted, then unshare a new mount namespace, mount it, issues the
@@ -168,10 +153,9 @@ asroot_iface_init_quirks(int ifindex, char *name)
 	 */
 
 	char command[] = "lldp stop";
-	char sysfs_path[SYSFS_PATH_MAX+1];
-	if (snprintf(sysfs_path, SYSFS_PATH_MAX,
-	    "/sys/kernel/debug/i40e/%.*s/command",
-	    (int)sizeof(ethc.bus_info), ethc.bus_info) >= SYSFS_PATH_MAX) {
+	char sysfs_path[SYSFS_PATH_MAX + 1];
+	if (snprintf(sysfs_path, SYSFS_PATH_MAX, "/sys/kernel/debug/i40e/%.*s/command",
+		(int)sizeof(ethc.bus_info), ethc.bus_info) >= SYSFS_PATH_MAX) {
 		log_warnx("interfaces", "path truncated");
 		goto end;
 	}
@@ -184,14 +168,12 @@ asroot_iface_init_quirks(int ifindex, char *name)
 			goto end;
 		}
 		log_warn("interfaces",
-		    "cannot open %s to disable LLDP in firmware for %s",
-		    sysfs_path, name);
+		    "cannot open %s to disable LLDP in firmware for %s", sysfs_path,
+		    name);
 		goto end;
 	}
 	if (write(fd, command, sizeof(command) - 1) == -1) {
-		log_warn("interfaces",
-		    "cannot disable LLDP in firmware for %s",
-		    name);
+		log_warn("interfaces", "cannot disable LLDP in firmware for %s", name);
 		goto end;
 	}
 end:
@@ -204,20 +186,15 @@ asroot_iface_init_os(int ifindex, char *name, int *fd)
 {
 	int rc;
 	/* Open listening socket to receive/send frames */
-	if ((*fd = socket(PF_PACKET, SOCK_RAW,
-		    htons(ETH_P_ALL))) < 0) {
+	if ((*fd = socket(PF_PACKET, SOCK_RAW, htons(ETH_P_ALL))) < 0) {
 		rc = errno;
 		return rc;
 	}
 
-	struct sockaddr_ll sa = {
-		.sll_family = AF_PACKET,
-		.sll_ifindex = ifindex
-	};
-	if (bind(*fd, (struct sockaddr*)&sa, sizeof(sa)) < 0) {
+	struct sockaddr_ll sa = { .sll_family = AF_PACKET, .sll_ifindex = ifindex };
+	if (bind(*fd, (struct sockaddr *)&sa, sizeof(sa)) < 0) {
 		rc = errno;
-		log_warn("privsep",
-		    "unable to bind to raw socket for interface %s",
+		log_warn("privsep", "unable to bind to raw socket for interface %s",
 		    name);
 		return rc;
 	}
@@ -225,12 +202,9 @@ asroot_iface_init_os(int ifindex, char *name, int *fd)
 	/* Set filter */
 	log_debug("privsep", "set BPF filter for %s", name);
 	static struct sock_filter lldpd_filter_f[] = { LLDPD_FILTER_F };
-	struct sock_fprog prog = {
-		.filter = lldpd_filter_f,
-		.len = sizeof(lldpd_filter_f) / sizeof(struct sock_filter)
-	};
-	if (setsockopt(*fd, SOL_SOCKET, SO_ATTACH_FILTER,
-	    &prog, sizeof(prog)) < 0) {
+	struct sock_fprog prog = { .filter = lldpd_filter_f,
+		.len = sizeof(lldpd_filter_f) / sizeof(struct sock_filter) };
+	if (setsockopt(*fd, SOL_SOCKET, SO_ATTACH_FILTER, &prog, sizeof(prog)) < 0) {
 		rc = errno;
 		log_warn("privsep", "unable to change filter for %s", name);
 		return rc;
@@ -248,8 +222,7 @@ asroot_iface_init_os(int ifindex, char *name, int *fd)
 
 #ifdef SO_LOCK_FILTER
 	int lock = 1;
-	if (setsockopt(*fd, SOL_SOCKET, SO_LOCK_FILTER,
-	    &lock, sizeof(lock)) < 0) {
+	if (setsockopt(*fd, SOL_SOCKET, SO_LOCK_FILTER, &lock, sizeof(lock)) < 0) {
 		if (errno != ENOPROTOOPT) {
 			rc = errno;
 			log_warn("privsep", "unable to lock filter for %s", name);
@@ -259,8 +232,8 @@ asroot_iface_init_os(int ifindex, char *name, int *fd)
 #endif
 #ifdef PACKET_IGNORE_OUTGOING
 	int ignore = 1;
-	if (setsockopt(*fd, SOL_PACKET, PACKET_IGNORE_OUTGOING,
-	    &ignore, sizeof(ignore)) < 0) {
+	if (setsockopt(*fd, SOL_PACKET, PACKET_IGNORE_OUTGOING, &ignore,
+		sizeof(ignore)) < 0) {
 		if (errno != ENOPROTOOPT) {
 			rc = errno;
 			log_warn("privsep",
@@ -282,7 +255,7 @@ asroot_iface_description_os(const char *name, const char *description)
 	 * process. Just write to /sys/class/net/XXXX/ifalias. */
 	char *file;
 #ifndef IFALIASZ
-# define IFALIASZ 256
+#  define IFALIASZ 256
 #endif
 	char descr[IFALIASZ];
 	FILE *fp;
@@ -292,7 +265,8 @@ asroot_iface_description_os(const char *name, const char *description)
 		return -1;
 	}
 	if (asprintf(&file, SYSFS_CLASS_NET "%s/ifalias", name) == -1) {
-		log_warn("privsep", "unable to allocate memory for setting description");
+		log_warn("privsep",
+		    "unable to allocate memory for setting description");
 		return -1;
 	}
 	if ((fp = fopen(file, "r+")) == NULL) {
@@ -303,8 +277,7 @@ asroot_iface_description_os(const char *name, const char *description)
 		return rc;
 	}
 	free(file);
-	if (strlen(description) == 0 &&
-	    fgets(descr, sizeof(descr), fp) != NULL) {
+	if (strlen(description) == 0 && fgets(descr, sizeof(descr), fp) != NULL) {
 		if (strncmp(descr, "lldpd: ", 7) == 0) {
 			if (strncmp(descr + 7, "was ", 4) == 0) {
 				/* Already has an old neighbor */
@@ -312,8 +285,7 @@ asroot_iface_description_os(const char *name, const char *description)
 				return 0;
 			} else {
 				/* Append was */
-				memmove(descr + 11, descr + 7,
-				    sizeof(descr) - 11);
+				memmove(descr + 11, descr + 7, sizeof(descr) - 11);
 				memcpy(descr, "lldpd: was ", 11);
 			}
 		} else {
@@ -323,8 +295,7 @@ asroot_iface_description_os(const char *name, const char *description)
 	} else
 		snprintf(descr, sizeof(descr), "lldpd: connected to %s", description);
 	if (fputs(descr, fp) == EOF) {
-		log_debug("privsep", "cannot set interface description for %s",
-		    name);
+		log_debug("privsep", "cannot set interface description for %s", name);
 		fclose(fp);
 		return -1;
 	}
@@ -336,8 +307,7 @@ int
 asroot_iface_promisc_os(const char *name)
 {
 	int s, rc;
-	if ((s = socket(PF_PACKET, SOCK_RAW,
-		    htons(ETH_P_ALL))) < 0) {
+	if ((s = socket(PF_PACKET, SOCK_RAW, htons(ETH_P_ALL))) < 0) {
 		rc = errno;
 		log_warn("privsep", "unable to open raw socket");
 		return rc;
@@ -348,8 +318,7 @@ asroot_iface_promisc_os(const char *name)
 
 	if (ioctl(s, SIOCGIFFLAGS, &ifr) == -1) {
 		rc = errno;
-		log_warn("privsep", "unable to get interface flags for %s",
-		    name);
+		log_warn("privsep", "unable to get interface flags for %s", name);
 		close(s);
 		return rc;
 	}
@@ -361,8 +330,7 @@ asroot_iface_promisc_os(const char *name)
 	ifr.ifr_flags |= IFF_PROMISC;
 	if (ioctl(s, SIOCSIFFLAGS, &ifr) == -1) {
 		rc = errno;
-		log_warn("privsep", "unable to set promisc mode for %s",
-		    name);
+		log_warn("privsep", "unable to set promisc mode for %s", name);
 		close(s);
 		return rc;
 	}
