@@ -24,19 +24,17 @@
 #include "../marshal.h"
 #include "../ctl.h"
 
-lldpctl_conn_t*
+lldpctl_conn_t *
 lldpctl_atom_get_connection(lldpctl_atom_t *atom)
 {
-	if (atom)
-		return atom->conn;
+	if (atom) return atom->conn;
 	return NULL;
 }
 
 void
 lldpctl_atom_inc_ref(lldpctl_atom_t *atom)
 {
-	if (atom)
-		atom->count++;
+	if (atom) atom->count++;
 }
 
 void
@@ -44,12 +42,10 @@ lldpctl_atom_dec_ref(lldpctl_atom_t *atom)
 {
 	struct atom_buffer *buffer, *buffer_next;
 	if (atom && (--atom->count == 0)) {
-		if (atom->free)
-			atom->free(atom);
+		if (atom->free) atom->free(atom);
 
 		/* Remove special allocated buffers */
-		for (buffer = TAILQ_FIRST(&atom->buffers);
-		     buffer;
+		for (buffer = TAILQ_FIRST(&atom->buffers); buffer;
 		     buffer = buffer_next) {
 			buffer_next = TAILQ_NEXT(buffer, next);
 			free(buffer);
@@ -59,7 +55,7 @@ lldpctl_atom_dec_ref(lldpctl_atom_t *atom)
 	}
 }
 
-lldpctl_atom_t*
+lldpctl_atom_t *
 lldpctl_atom_get(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
 	if (atom == NULL) return NULL;
@@ -72,9 +68,8 @@ lldpctl_atom_get(lldpctl_atom_t *atom, lldpctl_key_t key)
 	return atom->get(atom, key);
 }
 
-lldpctl_atom_t*
-lldpctl_atom_set(lldpctl_atom_t *atom, lldpctl_key_t key,
-    lldpctl_atom_t *value)
+lldpctl_atom_t *
+lldpctl_atom_set(lldpctl_atom_t *atom, lldpctl_key_t key, lldpctl_atom_t *value)
 {
 	if (atom == NULL) return NULL;
 	RESET_ERROR(atom->conn);
@@ -86,7 +81,7 @@ lldpctl_atom_set(lldpctl_atom_t *atom, lldpctl_key_t key,
 	return atom->set(atom, key, value);
 }
 
-const char*
+const char *
 lldpctl_atom_get_str(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
 	char *strresult = NULL;
@@ -112,9 +107,9 @@ lldpctl_atom_get_str(lldpctl_atom_t *atom, lldpctl_key_t key)
 			strresult = _lldpctl_alloc_in_atom(atom, 21);
 			if (!strresult) return NULL;
 			n1 = snprintf(strresult, 21, "%ld", intresult);
-			if (n1 > -1 && n1 < 21)
-				return strresult;
-			SET_ERROR(atom->conn, LLDPCTL_ERR_NOMEM); /* Not really true... */
+			if (n1 > -1 && n1 < 21) return strresult;
+			SET_ERROR(atom->conn,
+			    LLDPCTL_ERR_NOMEM); /* Not really true... */
 			return NULL;
 		}
 	}
@@ -132,9 +127,8 @@ lldpctl_atom_get_str(lldpctl_atom_t *atom, lldpctl_key_t key)
 	return NULL;
 }
 
-lldpctl_atom_t*
-lldpctl_atom_set_str(lldpctl_atom_t *atom, lldpctl_key_t key,
-	const char *value)
+lldpctl_atom_t *
+lldpctl_atom_set_str(lldpctl_atom_t *atom, lldpctl_key_t key, const char *value)
 {
 	lldpctl_atom_t *result = NULL;
 	const char *errstr;
@@ -171,7 +165,8 @@ lldpctl_atom_set_str(lldpctl_atom_t *atom, lldpctl_key_t key,
 
 	RESET_ERROR(atom->conn);
 	if (atom->set_buffer != NULL) {
-		result = atom->set_buffer(atom, key, (u_int8_t*)value, value?strlen(value):0);
+		result = atom->set_buffer(atom, key, (u_int8_t *)value,
+		    value ? strlen(value) : 0);
 		if (result) return result;
 		if (lldpctl_last_error(atom->conn) != LLDPCTL_ERR_NOT_EXIST &&
 		    lldpctl_last_error(atom->conn) != LLDPCTL_ERR_BAD_VALUE)
@@ -179,13 +174,12 @@ lldpctl_atom_set_str(lldpctl_atom_t *atom, lldpctl_key_t key,
 		bad = bad || (lldpctl_last_error(atom->conn) == LLDPCTL_ERR_BAD_VALUE);
 	}
 
-	SET_ERROR(atom->conn, bad?LLDPCTL_ERR_BAD_VALUE:LLDPCTL_ERR_NOT_EXIST);
+	SET_ERROR(atom->conn, bad ? LLDPCTL_ERR_BAD_VALUE : LLDPCTL_ERR_NOT_EXIST);
 	return NULL;
 }
 
-const u_int8_t*
-lldpctl_atom_get_buffer(lldpctl_atom_t *atom, lldpctl_key_t key,
-    size_t *length)
+const u_int8_t *
+lldpctl_atom_get_buffer(lldpctl_atom_t *atom, lldpctl_key_t key, size_t *length)
 {
 	if (atom == NULL) return NULL;
 	RESET_ERROR(atom->conn);
@@ -197,9 +191,9 @@ lldpctl_atom_get_buffer(lldpctl_atom_t *atom, lldpctl_key_t key,
 	return atom->get_buffer(atom, key, length);
 }
 
-lldpctl_atom_t*
-lldpctl_atom_set_buffer(lldpctl_atom_t *atom, lldpctl_key_t key,
-    const u_int8_t* value, size_t length)
+lldpctl_atom_t *
+lldpctl_atom_set_buffer(lldpctl_atom_t *atom, lldpctl_key_t key, const u_int8_t *value,
+    size_t length)
 {
 	if (atom == NULL) return NULL;
 	RESET_ERROR(atom->conn);
@@ -217,14 +211,12 @@ lldpctl_atom_get_int(lldpctl_atom_t *atom, lldpctl_key_t key)
 	if (atom == NULL) return LLDPCTL_ERR_NOT_EXIST;
 	RESET_ERROR(atom->conn);
 
-	if (atom->get_int == NULL)
-		return SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
+	if (atom->get_int == NULL) return SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
 	return atom->get_int(atom, key);
 }
 
-lldpctl_atom_t*
-lldpctl_atom_set_int(lldpctl_atom_t *atom, lldpctl_key_t key,
-    long int value)
+lldpctl_atom_t *
+lldpctl_atom_set_int(lldpctl_atom_t *atom, lldpctl_key_t key, long int value)
 {
 	if (atom == NULL) return NULL;
 	RESET_ERROR(atom->conn);
@@ -236,7 +228,7 @@ lldpctl_atom_set_int(lldpctl_atom_t *atom, lldpctl_key_t key,
 	return atom->set_int(atom, key, value);
 }
 
-lldpctl_atom_iter_t*
+lldpctl_atom_iter_t *
 lldpctl_atom_iter(lldpctl_atom_t *atom)
 {
 	if (atom == NULL) return NULL;
@@ -249,7 +241,7 @@ lldpctl_atom_iter(lldpctl_atom_t *atom)
 	return atom->iter(atom);
 }
 
-lldpctl_atom_iter_t*
+lldpctl_atom_iter_t *
 lldpctl_atom_iter_next(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 {
 	if (atom == NULL) return NULL;
@@ -262,8 +254,8 @@ lldpctl_atom_iter_next(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 	return atom->next(atom, iter);
 }
 
-lldpctl_atom_t*
-lldpctl_atom_iter_value(lldpctl_atom_t *atom,  lldpctl_atom_iter_t *iter)
+lldpctl_atom_t *
+lldpctl_atom_iter_value(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 {
 	if (atom == NULL) return NULL;
 	RESET_ERROR(atom->conn);
@@ -275,7 +267,7 @@ lldpctl_atom_iter_value(lldpctl_atom_t *atom,  lldpctl_atom_iter_t *iter)
 	return atom->value(atom, iter);
 }
 
-lldpctl_atom_t*
+lldpctl_atom_t *
 lldpctl_atom_create(lldpctl_atom_t *atom)
 {
 	if (atom == NULL) return NULL;
@@ -306,11 +298,9 @@ lldpctl_atom_create(lldpctl_atom_t *atom)
  * state_recv and in the two later cases, the provided @c state_data must match.
  */
 int
-_lldpctl_do_something(lldpctl_conn_t *conn,
-    int state_send, int state_recv, const char *state_data,
-    enum hmsg_type type,
-    void *to_send, struct marshal_info *mi_send,
-    void **to_recv, struct marshal_info *mi_recv)
+_lldpctl_do_something(lldpctl_conn_t *conn, int state_send, int state_recv,
+    const char *state_data, enum hmsg_type type, void *to_send,
+    struct marshal_info *mi_send, void **to_recv, struct marshal_info *mi_recv)
 {
 	ssize_t rc;
 
@@ -321,8 +311,8 @@ _lldpctl_do_something(lldpctl_conn_t *conn,
 	if (conn->state == CONN_STATE_IDLE) {
 		/* We need to build the message to send, then send
 		 * it. */
-		if (ctl_msg_send_unserialized(&conn->output_buffer, &conn->output_buffer_len,
-			type, to_send, mi_send) != 0)
+		if (ctl_msg_send_unserialized(&conn->output_buffer,
+			&conn->output_buffer_len, type, to_send, mi_send) != 0)
 			return SET_ERROR(conn, LLDPCTL_ERR_SERIALIZATION);
 		conn->state = state_send;
 		if (state_data)
@@ -331,26 +321,24 @@ _lldpctl_do_something(lldpctl_conn_t *conn,
 			conn->state_data[0] = 0;
 	}
 	if (conn->state == state_send &&
-	    (state_data == NULL || !strncmp(conn->state_data, state_data, sizeof(conn->state_data) - 1))) {
+	    (state_data == NULL ||
+		!strncmp(conn->state_data, state_data, sizeof(conn->state_data) - 1))) {
 		/* We need to send the currently built message */
 		rc = lldpctl_send(conn);
-		if (rc < 0)
-			return SET_ERROR(conn, rc);
+		if (rc < 0) return SET_ERROR(conn, rc);
 		conn->state = state_recv;
 	}
 	if (conn->state == state_recv &&
-	    (state_data == NULL || !strncmp(conn->state_data, state_data, sizeof(conn->state_data) - 1))) {
+	    (state_data == NULL ||
+		!strncmp(conn->state_data, state_data, sizeof(conn->state_data) - 1))) {
 		/* We need to receive the answer */
 		while ((rc = ctl_msg_recv_unserialized(&conn->input_buffer,
-			    &conn->input_buffer_len,
-			    type, to_recv, mi_recv)) > 0) {
+			    &conn->input_buffer_len, type, to_recv, mi_recv)) > 0) {
 			/* We need more bytes */
 			rc = _lldpctl_needs(conn, rc);
-			if (rc < 0)
-				return SET_ERROR(conn, rc);
+			if (rc < 0) return SET_ERROR(conn, rc);
 		}
-		if (rc < 0)
-			return SET_ERROR(conn, LLDPCTL_ERR_SERIALIZATION);
+		if (rc < 0) return SET_ERROR(conn, LLDPCTL_ERR_SERIALIZATION);
 		/* rc == 0 */
 		conn->state = CONN_STATE_IDLE;
 		conn->state_data[0] = 0;
@@ -359,19 +347,15 @@ _lldpctl_do_something(lldpctl_conn_t *conn,
 		return SET_ERROR(conn, LLDPCTL_ERR_INVALID_STATE);
 }
 
-
 int
-lldpctl_watch_callback(lldpctl_conn_t *conn,
-    lldpctl_change_callback cb,
-    void *data)
+lldpctl_watch_callback(lldpctl_conn_t *conn, lldpctl_change_callback cb, void *data)
 {
 	int rc;
 
 	RESET_ERROR(conn);
 
-	rc = _lldpctl_do_something(conn,
-	    CONN_STATE_SET_WATCH_SEND, CONN_STATE_SET_WATCH_RECV, NULL,
-	    SUBSCRIBE, NULL, NULL, NULL, NULL);
+	rc = _lldpctl_do_something(conn, CONN_STATE_SET_WATCH_SEND,
+	    CONN_STATE_SET_WATCH_RECV, NULL, SUBSCRIBE, NULL, NULL, NULL, NULL);
 	if (rc == 0) {
 		conn->watch_cb = cb;
 		conn->watch_data = data;
@@ -381,17 +365,14 @@ lldpctl_watch_callback(lldpctl_conn_t *conn,
 }
 
 int
-lldpctl_watch_callback2(lldpctl_conn_t *conn,
-    lldpctl_change_callback2 cb,
-    void *data)
+lldpctl_watch_callback2(lldpctl_conn_t *conn, lldpctl_change_callback2 cb, void *data)
 {
 	int rc;
 
 	RESET_ERROR(conn);
 
-	rc = _lldpctl_do_something(conn,
-	    CONN_STATE_SET_WATCH_SEND, CONN_STATE_SET_WATCH_RECV, NULL,
-	    SUBSCRIBE, NULL, NULL, NULL, NULL);
+	rc = _lldpctl_do_something(conn, CONN_STATE_SET_WATCH_SEND,
+	    CONN_STATE_SET_WATCH_RECV, NULL, SUBSCRIBE, NULL, NULL, NULL, NULL);
 	if (rc == 0) {
 		conn->watch_cb2 = cb;
 		conn->watch_data = data;
@@ -413,15 +394,14 @@ lldpctl_watch(lldpctl_conn_t *conn)
 	conn->watch_triggered = 0;
 	while (!conn->watch_triggered) {
 		rc = _lldpctl_needs(conn, 1);
-		if (rc < 0)
-			return SET_ERROR(conn, rc);
+		if (rc < 0) return SET_ERROR(conn, rc);
 	}
 
 	RESET_ERROR(conn);
 	return 0;
 }
 
-lldpctl_atom_t*
+lldpctl_atom_t *
 lldpctl_get_configuration(lldpctl_conn_t *conn)
 {
 	int rc;
@@ -430,11 +410,9 @@ lldpctl_get_configuration(lldpctl_conn_t *conn)
 
 	RESET_ERROR(conn);
 
-	rc = _lldpctl_do_something(conn,
-	    CONN_STATE_GET_CONFIG_SEND, CONN_STATE_GET_CONFIG_RECV, NULL,
-	    GET_CONFIG,
-	    NULL, NULL,
-	    &p, &MARSHAL_INFO(lldpd_config));
+	rc = _lldpctl_do_something(conn, CONN_STATE_GET_CONFIG_SEND,
+	    CONN_STATE_GET_CONFIG_RECV, NULL, GET_CONFIG, NULL, NULL, &p,
+	    &MARSHAL_INFO(lldpd_config));
 	if (rc == 0) {
 		config = p;
 		return _lldpctl_new_atom(conn, atom_config, config);
@@ -442,7 +420,7 @@ lldpctl_get_configuration(lldpctl_conn_t *conn)
 	return NULL;
 }
 
-lldpctl_atom_t*
+lldpctl_atom_t *
 lldpctl_get_interfaces(lldpctl_conn_t *conn)
 {
 	struct lldpd_interface_list *ifs;
@@ -451,11 +429,9 @@ lldpctl_get_interfaces(lldpctl_conn_t *conn)
 
 	RESET_ERROR(conn);
 
-	rc = _lldpctl_do_something(conn,
-	    CONN_STATE_GET_INTERFACES_SEND, CONN_STATE_GET_INTERFACES_RECV, NULL,
-	    GET_INTERFACES,
-	    NULL, NULL,
-	    &p, &MARSHAL_INFO(lldpd_interface_list));
+	rc = _lldpctl_do_something(conn, CONN_STATE_GET_INTERFACES_SEND,
+	    CONN_STATE_GET_INTERFACES_RECV, NULL, GET_INTERFACES, NULL, NULL, &p,
+	    &MARSHAL_INFO(lldpd_interface_list));
 	if (rc == 0) {
 		ifs = p;
 		return _lldpctl_new_atom(conn, atom_interfaces_list, ifs);
@@ -463,7 +439,7 @@ lldpctl_get_interfaces(lldpctl_conn_t *conn)
 	return NULL;
 }
 
-lldpctl_atom_t*
+lldpctl_atom_t *
 lldpctl_get_local_chassis(lldpctl_conn_t *conn)
 {
 	struct lldpd_chassis *chassis;
@@ -472,11 +448,9 @@ lldpctl_get_local_chassis(lldpctl_conn_t *conn)
 
 	RESET_ERROR(conn);
 
-	rc = _lldpctl_do_something(conn,
-	    CONN_STATE_GET_CHASSIS_SEND, CONN_STATE_GET_CHASSIS_RECV, NULL,
-	    GET_CHASSIS,
-	    NULL, NULL,
-	    &p, &MARSHAL_INFO(lldpd_chassis));
+	rc = _lldpctl_do_something(conn, CONN_STATE_GET_CHASSIS_SEND,
+	    CONN_STATE_GET_CHASSIS_RECV, NULL, GET_CHASSIS, NULL, NULL, &p,
+	    &MARSHAL_INFO(lldpd_chassis));
 	if (rc == 0) {
 		chassis = p;
 		return _lldpctl_new_atom(conn, atom_chassis, chassis, NULL, 0);
@@ -484,7 +458,7 @@ lldpctl_get_local_chassis(lldpctl_conn_t *conn)
 	return NULL;
 }
 
-lldpctl_atom_t*
+lldpctl_atom_t *
 lldpctl_get_port(lldpctl_atom_t *atom)
 {
 	int rc;
@@ -500,19 +474,18 @@ lldpctl_get_port(lldpctl_atom_t *atom)
 		SET_ERROR(conn, LLDPCTL_ERR_INCORRECT_ATOM_TYPE);
 		return NULL;
 	}
-	rc = _lldpctl_do_something(conn,
-	    CONN_STATE_GET_PORT_SEND, CONN_STATE_GET_PORT_RECV, iface->name,
-	    GET_INTERFACE, (void*)iface->name, &MARSHAL_INFO(string),
-	    &p, &MARSHAL_INFO(lldpd_hardware));
+	rc = _lldpctl_do_something(conn, CONN_STATE_GET_PORT_SEND,
+	    CONN_STATE_GET_PORT_RECV, iface->name, GET_INTERFACE, (void *)iface->name,
+	    &MARSHAL_INFO(string), &p, &MARSHAL_INFO(lldpd_hardware));
 	if (rc == 0) {
 		hardware = p;
-		return _lldpctl_new_atom(conn, atom_port, 1,
-		    hardware, &hardware->h_lport, NULL);
+		return _lldpctl_new_atom(conn, atom_port, 1, hardware,
+		    &hardware->h_lport, NULL);
 	}
 	return NULL;
 }
 
-lldpctl_atom_t*
+lldpctl_atom_t *
 lldpctl_get_default_port(lldpctl_conn_t *conn)
 {
 	struct lldpd_port *port;
@@ -521,10 +494,9 @@ lldpctl_get_default_port(lldpctl_conn_t *conn)
 
 	RESET_ERROR(conn);
 
-	rc = _lldpctl_do_something(conn,
-	    CONN_STATE_GET_DEFAULT_PORT_SEND, CONN_STATE_GET_DEFAULT_PORT_RECV, "",
-	    GET_DEFAULT_PORT, NULL, NULL,
-	    &p, &MARSHAL_INFO(lldpd_port));
+	rc = _lldpctl_do_something(conn, CONN_STATE_GET_DEFAULT_PORT_SEND,
+	    CONN_STATE_GET_DEFAULT_PORT_RECV, "", GET_DEFAULT_PORT, NULL, NULL, &p,
+	    &MARSHAL_INFO(lldpd_port));
 	if (rc == 0) {
 		port = p;
 		return _lldpctl_new_atom(conn, atom_port, 1, NULL, port, NULL);
@@ -532,28 +504,26 @@ lldpctl_get_default_port(lldpctl_conn_t *conn)
 	return NULL;
 }
 
-static lldpctl_map_t empty_map[] = {{ 0, NULL }};
+static lldpctl_map_t empty_map[] = { { 0, NULL } };
 
-static struct atom_map atom_map_list = {
-	.next = NULL
-};
+static struct atom_map atom_map_list = { .next = NULL };
 
-lldpctl_map_t*
+lldpctl_map_t *
 lldpctl_key_get_map(lldpctl_key_t key)
 {
 	init_atom_map();
 	struct atom_map *map;
-	for (map = atom_map_list.next; map ; map = map->next) {
-		if (map->key == key)
-			return map->map;
+	for (map = atom_map_list.next; map; map = map->next) {
+		if (map->key == key) return map->map;
 	}
 	return empty_map;
 }
 
-void atom_map_register(struct atom_map *map, int prio)
+void
+atom_map_register(struct atom_map *map, int prio)
 {
 	(void)prio;
-	struct atom_map* iter = &atom_map_list;
+	struct atom_map *iter = &atom_map_list;
 
 	while (iter->next)
 		iter = iter->next;
@@ -561,14 +531,13 @@ void atom_map_register(struct atom_map *map, int prio)
 	iter->next = map;
 }
 
-static struct atom_builder atom_builder_list = {
-	.nextb = NULL
-};
+static struct atom_builder atom_builder_list = { .nextb = NULL };
 
-void atom_builder_register(struct atom_builder *builder, int prio)
+void
+atom_builder_register(struct atom_builder *builder, int prio)
 {
 	(void)prio;
-	struct atom_builder* iter = &atom_builder_list;
+	struct atom_builder *iter = &atom_builder_list;
 
 	while (iter->nextb)
 		iter = iter->nextb;
@@ -576,14 +545,14 @@ void atom_builder_register(struct atom_builder *builder, int prio)
 	iter->nextb = builder;
 }
 
-lldpctl_atom_t*
+lldpctl_atom_t *
 _lldpctl_new_atom(lldpctl_conn_t *conn, atom_t type, ...)
 {
 	init_atom_builder();
 	struct atom_builder *builder;
 	struct lldpctl_atom_t *atom;
 	va_list(ap);
-	for (builder = atom_builder_list.nextb; builder ; builder = builder->nextb) {
+	for (builder = atom_builder_list.nextb; builder; builder = builder->nextb) {
 		if (builder->type != type) continue;
 		atom = calloc(1, builder->size);
 		if (atom == NULL) {
@@ -591,25 +560,25 @@ _lldpctl_new_atom(lldpctl_conn_t *conn, atom_t type, ...)
 			return NULL;
 		}
 		atom->count = 1;
-		atom->type  = type;
-		atom->conn  = conn;
+		atom->type = type;
+		atom->conn = conn;
 		TAILQ_INIT(&atom->buffers);
-		atom->free  = builder->free;
+		atom->free = builder->free;
 
-		atom->iter  = builder->iter;
-		atom->next  = builder->next;
+		atom->iter = builder->iter;
+		atom->next = builder->next;
 		atom->value = builder->value;
 
-		atom->get       = builder->get;
-		atom->get_str   = builder->get_str;
-		atom->get_buffer= builder->get_buffer;
-		atom->get_int   = builder->get_int;
+		atom->get = builder->get;
+		atom->get_str = builder->get_str;
+		atom->get_buffer = builder->get_buffer;
+		atom->get_int = builder->get_int;
 
-		atom->set       = builder->set;
-		atom->set_str   = builder->set_str;
-		atom->set_buffer= builder->set_buffer;
-		atom->set_int   = builder->set_int;
-		atom->create    = builder->create;
+		atom->set = builder->set;
+		atom->set_str = builder->set_str;
+		atom->set_buffer = builder->set_buffer;
+		atom->set_int = builder->set_int;
+		atom->create = builder->create;
 
 		va_start(ap, type);
 		if (builder->init && builder->init(atom, ap) == 0) {
@@ -636,7 +605,7 @@ _lldpctl_new_atom(lldpctl_conn_t *conn, atom_t type, ...)
  * @param size Size of the allocated area.
  * @return Pointer to the buffer or @c NULL if allocation fails.
  */
-void*
+void *
 _lldpctl_alloc_in_atom(lldpctl_atom_t *atom, size_t size)
 {
 	struct atom_buffer *buffer;
@@ -661,10 +630,9 @@ _lldpctl_alloc_in_atom(lldpctl_atom_t *atom, size_t size)
  * @param max    Maximum number of bytes to dump. Can be 0 if no maximum.
  * @return A string representing the dump of the buffer or @c NULL if error.
  */
-const char*
-_lldpctl_dump_in_atom(lldpctl_atom_t *atom,
-    const uint8_t *input, size_t size,
-    char sep, size_t max)
+const char *
+_lldpctl_dump_in_atom(lldpctl_atom_t *atom, const uint8_t *input, size_t size, char sep,
+    size_t max)
 {
 	static const char truncation[] = "[...]";
 	size_t i, len;
@@ -675,14 +643,13 @@ _lldpctl_dump_in_atom(lldpctl_atom_t *atom,
 	else
 		len = size * 3 + 1;
 
-	if ((buffer = _lldpctl_alloc_in_atom(atom, len)) == NULL)
-		return NULL;
+	if ((buffer = _lldpctl_alloc_in_atom(atom, len)) == NULL) return NULL;
 
 	for (i = 0; (i < size) && (max == 0 || i < max); i++)
-		snprintf(buffer + i * 3, 4, "%02x%c", *(u_int8_t*)(input + i), sep);
+		snprintf(buffer + i * 3, 4, "%02x%c", *(u_int8_t *)(input + i), sep);
 	if (max > 0 && size > max)
 		snprintf(buffer + i * 3, sizeof(truncation) + 1, "%s", truncation);
 	else
-		*(buffer + i*3 - 1) = 0;
+		*(buffer + i * 3 - 1) = 0;
 	return buffer;
 }
