@@ -37,26 +37,26 @@ static lldpctl_map_t port_med_location_map[] = {
 
 static lldpctl_map_t port_med_pow_devicetype_map[] = {
 	{ LLDP_MED_POW_TYPE_PSE, "PSE" },
-	{ LLDP_MED_POW_TYPE_PD,  "PD" },
+	{ LLDP_MED_POW_TYPE_PD, "PD" },
 	{ 0, NULL },
 };
 
 static lldpctl_map_t port_med_pow_source_map[] = {
 	{ LLDP_MED_POW_SOURCE_PRIMARY, "Primary Power Source" },
-	{ LLDP_MED_POW_SOURCE_BACKUP,  "Backup Power Source / Power Conservation Mode" },
-	{ LLDP_MED_POW_SOURCE_PSE,     "PSE" },
-	{ LLDP_MED_POW_SOURCE_LOCAL,   "Local"},
-	{ LLDP_MED_POW_SOURCE_BOTH,    "PSE + Local"},
+	{ LLDP_MED_POW_SOURCE_BACKUP, "Backup Power Source / Power Conservation Mode" },
+	{ LLDP_MED_POW_SOURCE_PSE, "PSE" },
+	{ LLDP_MED_POW_SOURCE_LOCAL, "Local" },
+	{ LLDP_MED_POW_SOURCE_BOTH, "PSE + Local" },
 	{ 0, NULL },
 };
 
 static lldpctl_map_t port_med_pow_source_map2[] = {
-	{ 0,                           "unknown" },
+	{ 0, "unknown" },
 	{ LLDP_MED_POW_SOURCE_PRIMARY, "primary" },
-	{ LLDP_MED_POW_SOURCE_BACKUP,  "backup" },
-	{ LLDP_MED_POW_SOURCE_PSE,     "pse" },
-	{ LLDP_MED_POW_SOURCE_LOCAL,   "local" },
-	{ LLDP_MED_POW_SOURCE_BOTH,    "both" },
+	{ LLDP_MED_POW_SOURCE_BACKUP, "backup" },
+	{ LLDP_MED_POW_SOURCE_PSE, "pse" },
+	{ LLDP_MED_POW_SOURCE_LOCAL, "local" },
+	{ LLDP_MED_POW_SOURCE_BOTH, "both" },
 	{ 0, NULL },
 };
 
@@ -99,20 +99,18 @@ static struct atom_map civic_address_type_map = {
 	},
 };
 
-static struct atom_map port_med_policy_map = {
-	.key = lldpctl_k_med_policy_type,
+static struct atom_map port_med_policy_map = { .key = lldpctl_k_med_policy_type,
 	.map = {
-		{ LLDP_MED_APPTYPE_VOICE ,           "Voice"},
-		{ LLDP_MED_APPTYPE_VOICESIGNAL,      "Voice Signaling"},
-		{ LLDP_MED_APPTYPE_GUESTVOICE,       "Guest Voice"},
-		{ LLDP_MED_APPTYPE_GUESTVOICESIGNAL, "Guest Voice Signaling"},
-		{ LLDP_MED_APPTYPE_SOFTPHONEVOICE,   "Softphone Voice"},
-		{ LLDP_MED_APPTYPE_VIDEOCONFERENCE,  "Video Conferencing"},
-		{ LLDP_MED_APPTYPE_VIDEOSTREAM,      "Streaming Video"},
-		{ LLDP_MED_APPTYPE_VIDEOSIGNAL,      "Video Signaling"},
-		{ 0, NULL },
-	}
-};
+	    { LLDP_MED_APPTYPE_VOICE, "Voice" },
+	    { LLDP_MED_APPTYPE_VOICESIGNAL, "Voice Signaling" },
+	    { LLDP_MED_APPTYPE_GUESTVOICE, "Guest Voice" },
+	    { LLDP_MED_APPTYPE_GUESTVOICESIGNAL, "Guest Voice Signaling" },
+	    { LLDP_MED_APPTYPE_SOFTPHONEVOICE, "Softphone Voice" },
+	    { LLDP_MED_APPTYPE_VIDEOCONFERENCE, "Video Conferencing" },
+	    { LLDP_MED_APPTYPE_VIDEOSTREAM, "Streaming Video" },
+	    { LLDP_MED_APPTYPE_VIDEOSIGNAL, "Video Signaling" },
+	    { 0, NULL },
+	} };
 
 static struct atom_map port_med_policy_prio_map = {
 	.key = lldpctl_k_med_policy_priority,
@@ -140,13 +138,13 @@ static struct atom_map port_med_pow_priority_map = {
 	},
 };
 
-ATOM_MAP_REGISTER(port_med_geoid_map,        7);
-ATOM_MAP_REGISTER(civic_address_type_map,    8);
-ATOM_MAP_REGISTER(port_med_policy_map,       9);
-ATOM_MAP_REGISTER(port_med_policy_prio_map,  10);
+ATOM_MAP_REGISTER(port_med_geoid_map, 7);
+ATOM_MAP_REGISTER(civic_address_type_map, 8);
+ATOM_MAP_REGISTER(port_med_policy_map, 9);
+ATOM_MAP_REGISTER(port_med_policy_prio_map, 10);
 ATOM_MAP_REGISTER(port_med_pow_priority_map, 11);
 
-static lldpctl_atom_iter_t*
+static lldpctl_atom_iter_t *
 _lldpctl_atom_iter_med_policies_list(lldpctl_atom_t *atom)
 {
 	int i;
@@ -154,18 +152,18 @@ _lldpctl_atom_iter_med_policies_list(lldpctl_atom_t *atom)
 	    (struct _lldpctl_atom_any_list_t *)atom;
 	for (i = 0; i < LLDP_MED_APPTYPE_LAST; i++)
 		vlist->parent->port->p_med_policy[i].index = i;
-	return (lldpctl_atom_iter_t*)&vlist->parent->port->p_med_policy[0];
+	return (lldpctl_atom_iter_t *)&vlist->parent->port->p_med_policy[0];
 }
 
-static lldpctl_atom_iter_t*
+static lldpctl_atom_iter_t *
 _lldpctl_atom_next_med_policies_list(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 {
 	struct lldpd_med_policy *policy = (struct lldpd_med_policy *)iter;
 	if (policy->index == LLDP_MED_APPTYPE_LAST - 1) return NULL;
-	return (lldpctl_atom_iter_t*)(++policy);
+	return (lldpctl_atom_iter_t *)(++policy);
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_value_med_policies_list(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 {
 	struct _lldpctl_atom_any_list_t *vlist =
@@ -218,7 +216,7 @@ _lldpctl_atom_get_int_med_policy(lldpctl_atom_t *atom, lldpctl_key_t key)
 	}
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_set_int_med_policy(lldpctl_atom_t *atom, lldpctl_key_t key,
     long int value)
 {
@@ -271,7 +269,7 @@ bad:
 	return NULL;
 }
 
-static const char*
+static const char *
 _lldpctl_atom_get_str_med_policy(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
 	struct _lldpctl_atom_med_policy_t *m =
@@ -289,7 +287,7 @@ _lldpctl_atom_get_str_med_policy(lldpctl_atom_t *atom, lldpctl_key_t key)
 	}
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_set_str_med_policy(lldpctl_atom_t *atom, lldpctl_key_t key,
     const char *value)
 {
@@ -307,7 +305,7 @@ _lldpctl_atom_set_str_med_policy(lldpctl_atom_t *atom, lldpctl_key_t key,
 	}
 }
 
-static lldpctl_atom_iter_t*
+static lldpctl_atom_iter_t *
 _lldpctl_atom_iter_med_locations_list(lldpctl_atom_t *atom)
 {
 	int i;
@@ -315,24 +313,25 @@ _lldpctl_atom_iter_med_locations_list(lldpctl_atom_t *atom)
 	    (struct _lldpctl_atom_any_list_t *)atom;
 	for (i = 0; i < LLDP_MED_LOCFORMAT_LAST; i++)
 		vlist->parent->port->p_med_location[i].index = i;
-	return (lldpctl_atom_iter_t*)&vlist->parent->port->p_med_location[0];
+	return (lldpctl_atom_iter_t *)&vlist->parent->port->p_med_location[0];
 }
 
-static lldpctl_atom_iter_t*
+static lldpctl_atom_iter_t *
 _lldpctl_atom_next_med_locations_list(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 {
 	struct lldpd_med_loc *location = (struct lldpd_med_loc *)iter;
 	if (location->index == LLDP_MED_LOCFORMAT_LAST - 1) return NULL;
-	return (lldpctl_atom_iter_t*)(++location);
+	return (lldpctl_atom_iter_t *)(++location);
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_value_med_locations_list(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 {
 	struct _lldpctl_atom_any_list_t *vlist =
 	    (struct _lldpctl_atom_any_list_t *)atom;
 	struct lldpd_med_loc *location = (struct lldpd_med_loc *)iter;
-	return _lldpctl_new_atom(atom->conn, atom_med_location, vlist->parent, location);
+	return _lldpctl_new_atom(atom->conn, atom_med_location, vlist->parent,
+	    location);
 }
 
 static int
@@ -369,8 +368,8 @@ _lldpctl_atom_get_int_med_location(lldpctl_atom_t *atom, lldpctl_key_t key)
 			return LLDP_MED_LOCFORMAT_COORD;
 		case LLDP_MED_LOCFORMAT_CIVIC:
 			if ((m->location->data_len < 3) ||
-			    (m->location->data_len - 1 <
-				m->location->data[0])) break;
+			    (m->location->data_len - 1 < m->location->data[0]))
+				break;
 			return LLDP_MED_LOCFORMAT_CIVIC;
 		case LLDP_MED_LOCFORMAT_ELIN:
 			return LLDP_MED_LOCFORMAT_ELIN;
@@ -391,7 +390,7 @@ _lldpctl_atom_get_int_med_location(lldpctl_atom_t *atom, lldpctl_key_t key)
 	}
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_set_int_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
     long int value)
 {
@@ -407,7 +406,7 @@ _lldpctl_atom_set_int_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 	switch (key) {
 	case lldpctl_k_med_location_format:
 		switch (value) {
-		case 0:		/* Disabling */
+		case 0: /* Disabling */
 		case LLDP_MED_LOCFORMAT_COORD:
 			mloc->location->format = value;
 			free(mloc->location->data);
@@ -440,11 +439,13 @@ _lldpctl_atom_set_int_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 			mloc->location->data = NULL;
 			mloc->location->data_len = 0;
 			return atom;
-		default: goto bad;
+		default:
+			goto bad;
 		}
 	case lldpctl_k_med_location_geoid:
 		if (mloc->location->format != LLDP_MED_LOCFORMAT_COORD) goto bad;
-		if (mloc->location->data == NULL || mloc->location->data_len != 16) goto bad;
+		if (mloc->location->data == NULL || mloc->location->data_len != 16)
+			goto bad;
 		switch (value) {
 		case 0:
 		case LLDP_MED_LOCATION_GEOID_WGS84:
@@ -452,11 +453,13 @@ _lldpctl_atom_set_int_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 		case LLDP_MED_LOCATION_GEOID_NAD83_MLLW:
 			mloc->location->data[15] = value;
 			return atom;
-		default: goto bad;
+		default:
+			goto bad;
 		}
 	case lldpctl_k_med_location_altitude_unit:
 		if (mloc->location->format != LLDP_MED_LOCFORMAT_COORD) goto bad;
-		if (mloc->location->data == NULL || mloc->location->data_len != 16) goto bad;
+		if (mloc->location->data == NULL || mloc->location->data_len != 16)
+			goto bad;
 		switch (value) {
 		case 0:
 		case LLDP_MED_LOCATION_ALTITUDE_UNIT_METER:
@@ -464,7 +467,8 @@ _lldpctl_atom_set_int_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 			mloc->location->data[10] &= 0x0f;
 			mloc->location->data[10] |= value << 4;
 			return atom;
-		default: goto bad;
+		default:
+			goto bad;
 		}
 	default:
 		SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
@@ -475,15 +479,14 @@ _lldpctl_atom_set_int_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 bad:
 	SET_ERROR(atom->conn, LLDPCTL_ERR_BAD_VALUE);
 	return NULL;
-
 }
 
-static const char*
-read_fixed_precision(lldpctl_atom_t *atom,
-    char *buffer, unsigned shift,
+static const char *
+read_fixed_precision(lldpctl_atom_t *atom, char *buffer, unsigned shift,
     unsigned intbits, unsigned fltbits, const char *suffix)
 {
-	struct fp_number fp = fp_buftofp((unsigned char*)buffer, intbits, fltbits, shift);
+	struct fp_number fp =
+	    fp_buftofp((unsigned char *)buffer, intbits, fltbits, shift);
 	char *result = fp_fptostr(fp, suffix);
 	if (result == NULL) {
 		SET_ERROR(atom->conn, LLDPCTL_ERR_NOMEM);
@@ -501,7 +504,7 @@ read_fixed_precision(lldpctl_atom_t *atom,
 	return stored;
 }
 
-static const char*
+static const char *
 _lldpctl_atom_get_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
 	struct _lldpctl_atom_med_location_t *m =
@@ -514,20 +517,16 @@ _lldpctl_atom_get_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key)
 		return map_lookup(port_med_location_map, m->location->format);
 	case lldpctl_k_med_location_geoid:
 		if (m->location->format != LLDP_MED_LOCFORMAT_COORD) break;
-		return map_lookup(port_med_geoid_map.map,
-		    m->location->data[15]);
+		return map_lookup(port_med_geoid_map.map, m->location->data[15]);
 	case lldpctl_k_med_location_latitude:
 		if (m->location->format != LLDP_MED_LOCFORMAT_COORD) break;
-		return read_fixed_precision(atom, m->location->data,
-		    0, 9, 25, "NS");
+		return read_fixed_precision(atom, m->location->data, 0, 9, 25, "NS");
 	case lldpctl_k_med_location_longitude:
 		if (m->location->format != LLDP_MED_LOCFORMAT_COORD) break;
-		return read_fixed_precision(atom, m->location->data,
-		    40, 9, 25, "EW");
+		return read_fixed_precision(atom, m->location->data, 40, 9, 25, "EW");
 	case lldpctl_k_med_location_altitude:
 		if (m->location->format != LLDP_MED_LOCFORMAT_COORD) break;
-		return read_fixed_precision(atom, m->location->data,
-		    84, 22, 8, NULL);
+		return read_fixed_precision(atom, m->location->data, 84, 22, 8, NULL);
 	case lldpctl_k_med_location_altitude_unit:
 		if (m->location->format != LLDP_MED_LOCFORMAT_COORD) break;
 		switch (m->location->data[10] & 0xf0) {
@@ -559,7 +558,7 @@ _lldpctl_atom_get_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key)
 	return NULL;
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_set_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
     const char *value)
 {
@@ -577,44 +576,51 @@ _lldpctl_atom_set_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 	switch (key) {
 	case lldpctl_k_med_location_latitude:
 		if (mloc->location->format != LLDP_MED_LOCFORMAT_COORD) goto bad;
-		if (mloc->location->data == NULL || mloc->location->data_len != 16) goto bad;
+		if (mloc->location->data == NULL || mloc->location->data_len != 16)
+			goto bad;
 		if (value) fp = fp_strtofp(value, &end, 9, 25);
 		if (!end) goto bad;
 		if (end && *end != '\0') {
-			if (*(end+1) != '\0') goto bad;
-			if (*end == 'S') fp = fp_negate(fp);
-			else if (*end != 'N') goto bad;
+			if (*(end + 1) != '\0') goto bad;
+			if (*end == 'S')
+				fp = fp_negate(fp);
+			else if (*end != 'N')
+				goto bad;
 		}
-		fp_fptobuf(fp, (unsigned char*)mloc->location->data, 0);
+		fp_fptobuf(fp, (unsigned char *)mloc->location->data, 0);
 		return atom;
 	case lldpctl_k_med_location_longitude:
 		if (mloc->location->format != LLDP_MED_LOCFORMAT_COORD) goto bad;
-		if (mloc->location->data == NULL || mloc->location->data_len != 16) goto bad;
+		if (mloc->location->data == NULL || mloc->location->data_len != 16)
+			goto bad;
 		if (value) fp = fp_strtofp(value, &end, 9, 25);
 		if (!end) goto bad;
 		if (end && *end != '\0') {
-			if (*(end+1) != '\0') goto bad;
-			if (*end == 'W') fp = fp_negate(fp);
-			else if (*end != 'E') goto bad;
+			if (*(end + 1) != '\0') goto bad;
+			if (*end == 'W')
+				fp = fp_negate(fp);
+			else if (*end != 'E')
+				goto bad;
 		}
-		fp_fptobuf(fp, (unsigned char*)mloc->location->data, 40);
+		fp_fptobuf(fp, (unsigned char *)mloc->location->data, 40);
 		return atom;
 	case lldpctl_k_med_location_altitude:
 		if (mloc->location->format != LLDP_MED_LOCFORMAT_COORD) goto bad;
-		if (mloc->location->data == NULL || mloc->location->data_len != 16) goto bad;
+		if (mloc->location->data == NULL || mloc->location->data_len != 16)
+			goto bad;
 		if (value) fp = fp_strtofp(value, &end, 22, 8);
 		if (!end || *end != '\0') goto bad;
-		fp_fptobuf(fp, (unsigned char*)mloc->location->data, 84);
+		fp_fptobuf(fp, (unsigned char *)mloc->location->data, 84);
 		return atom;
 	case lldpctl_k_med_location_altitude_unit:
 		if (!value) goto bad;
 		if (mloc->location->format != LLDP_MED_LOCFORMAT_COORD) goto bad;
-		if (mloc->location->data == NULL || mloc->location->data_len != 16) goto bad;
+		if (mloc->location->data == NULL || mloc->location->data_len != 16)
+			goto bad;
 		if (!strcmp(value, "m"))
 			return _lldpctl_atom_set_int_med_location(atom, key,
 			    LLDP_MED_LOCATION_ALTITUDE_UNIT_METER);
-		if (!strcmp(value, "f") ||
-		    (!strcmp(value, "floor")))
+		if (!strcmp(value, "f") || (!strcmp(value, "floor")))
 			return _lldpctl_atom_set_int_med_location(atom, key,
 			    LLDP_MED_LOCATION_ALTITUDE_UNIT_FLOOR);
 		goto bad;
@@ -624,7 +630,8 @@ _lldpctl_atom_set_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 		    map_reverse_lookup(port_med_geoid_map.map, value));
 	case lldpctl_k_med_location_country:
 		if (mloc->location->format != LLDP_MED_LOCFORMAT_CIVIC) goto bad;
-		if (mloc->location->data == NULL || mloc->location->data_len < 3) goto bad;
+		if (mloc->location->data == NULL || mloc->location->data_len < 3)
+			goto bad;
 		if (!value || strlen(value) != 2) goto bad;
 		memcpy(mloc->location->data + 2, value, 2);
 		return atom;
@@ -639,8 +646,7 @@ _lldpctl_atom_set_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 			return NULL;
 		}
 		mloc->location->data_len = strlen(value);
-		memcpy(mloc->location->data, value,
-		    mloc->location->data_len);
+		memcpy(mloc->location->data, value, mloc->location->data_len);
 		return atom;
 	default:
 		SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
@@ -651,10 +657,9 @@ _lldpctl_atom_set_str_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 bad:
 	SET_ERROR(atom->conn, LLDPCTL_ERR_BAD_VALUE);
 	return NULL;
-
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_get_atom_med_location(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
 	struct _lldpctl_atom_med_location_t *m =
@@ -674,7 +679,7 @@ _lldpctl_atom_get_atom_med_location(lldpctl_atom_t *atom, lldpctl_key_t key)
 	}
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_set_atom_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
     lldpctl_atom_t *value)
 {
@@ -711,7 +716,7 @@ _lldpctl_atom_set_atom_med_location(lldpctl_atom_t *atom, lldpctl_key_t key,
 		memcpy(new + m->location->data_len + 2, el->value, el->len);
 		new[0] += 2 + el->len;
 		free(m->location->data);
-		m->location->data = (char*)new;
+		m->location->data = (char *)new;
 		m->location->data_len += 2 + el->len;
 		return atom;
 	default:
@@ -728,22 +733,22 @@ struct ca_iter {
 	size_t data_len;
 };
 
-static lldpctl_atom_iter_t*
+static lldpctl_atom_iter_t *
 _lldpctl_atom_iter_med_caelements_list(lldpctl_atom_t *atom)
 {
 	struct _lldpctl_atom_med_caelements_list_t *plist =
 	    (struct _lldpctl_atom_med_caelements_list_t *)atom;
 	struct ca_iter *iter;
 	if (plist->parent->location->data_len < 4 ||
-	    *(uint8_t*)plist->parent->location->data < 3 ||
+	    *(uint8_t *)plist->parent->location->data < 3 ||
 	    !(iter = _lldpctl_alloc_in_atom(atom, sizeof(struct ca_iter))))
 		return NULL;
-	iter->data = (uint8_t*)plist->parent->location->data + 4;
-	iter->data_len = *(uint8_t*)plist->parent->location->data - 3;
-	return (lldpctl_atom_iter_t*)iter;
+	iter->data = (uint8_t *)plist->parent->location->data + 4;
+	iter->data_len = *(uint8_t *)plist->parent->location->data - 3;
+	return (lldpctl_atom_iter_t *)iter;
 }
 
-static lldpctl_atom_iter_t*
+static lldpctl_atom_iter_t *
 _lldpctl_atom_next_med_caelements_list(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 {
 	struct ca_iter *cai = (struct ca_iter *)iter;
@@ -753,10 +758,10 @@ _lldpctl_atom_next_med_caelements_list(lldpctl_atom_t *atom, lldpctl_atom_iter_t
 	if (cai->data_len < 2 + len) return NULL;
 	cai->data += 2 + len;
 	cai->data_len -= 2 + len;
-	return (lldpctl_atom_iter_t*)cai;
+	return (lldpctl_atom_iter_t *)cai;
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_value_med_caelements_list(lldpctl_atom_t *atom, lldpctl_atom_iter_t *iter)
 {
 	struct _lldpctl_atom_med_caelements_list_t *plist =
@@ -770,13 +775,13 @@ _lldpctl_atom_value_med_caelements_list(lldpctl_atom_t *atom, lldpctl_atom_iter_
 	    (int)*cai->data, cai->data + 2, len);
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_create_med_caelements_list(lldpctl_atom_t *atom)
 {
 	struct _lldpctl_atom_med_caelements_list_t *plist =
 	    (struct _lldpctl_atom_med_caelements_list_t *)atom;
-	return _lldpctl_new_atom(atom->conn, atom_med_caelement, plist->parent,
-	    -1, NULL, 0);
+	return _lldpctl_new_atom(atom->conn, atom_med_caelement, plist->parent, -1,
+	    NULL, 0);
 }
 
 static int
@@ -785,9 +790,9 @@ _lldpctl_atom_new_med_caelement(lldpctl_atom_t *atom, va_list ap)
 	struct _lldpctl_atom_med_caelement_t *el =
 	    (struct _lldpctl_atom_med_caelement_t *)atom;
 	el->parent = va_arg(ap, struct _lldpctl_atom_med_location_t *);
-	el->type   = va_arg(ap, int);
-	el->value  = va_arg(ap, uint8_t*);
-	el->len    = va_arg(ap, size_t);
+	el->type = va_arg(ap, int);
+	el->value = va_arg(ap, uint8_t *);
+	el->len = va_arg(ap, size_t);
 	lldpctl_atom_inc_ref((lldpctl_atom_t *)el->parent);
 	return 1;
 }
@@ -814,7 +819,7 @@ _lldpctl_atom_get_int_med_caelement(lldpctl_atom_t *atom, lldpctl_key_t key)
 	}
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_set_int_med_caelement(lldpctl_atom_t *atom, lldpctl_key_t key,
     long int value)
 {
@@ -843,7 +848,7 @@ bad:
 	return NULL;
 }
 
-static const char*
+static const char *
 _lldpctl_atom_get_str_med_caelement(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
 	char *value = NULL;
@@ -865,7 +870,7 @@ _lldpctl_atom_get_str_med_caelement(lldpctl_atom_t *atom, lldpctl_key_t key)
 	}
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_set_str_med_caelement(lldpctl_atom_t *atom, lldpctl_key_t key,
     const char *value)
 {
@@ -886,7 +891,7 @@ _lldpctl_atom_set_str_med_caelement(lldpctl_atom_t *atom, lldpctl_key_t key,
 		if (len > 251) goto bad;
 		el->value = _lldpctl_alloc_in_atom(atom, len);
 		if (el->value == NULL) return NULL;
-		strlcpy((char*)el->value, value, len);
+		strlcpy((char *)el->value, value, len);
 		el->len = strlen(value);
 		return atom;
 	case lldpctl_k_med_civicaddress_type:
@@ -921,7 +926,7 @@ _lldpctl_atom_free_med_power(lldpctl_atom_t *atom)
 	lldpctl_atom_dec_ref((lldpctl_atom_t *)mpow->parent);
 }
 
-static const char*
+static const char *
 _lldpctl_atom_get_str_med_power(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
 	struct _lldpctl_atom_med_power_t *mpow =
@@ -934,8 +939,7 @@ _lldpctl_atom_get_str_med_power(lldpctl_atom_t *atom, lldpctl_key_t key)
 		return map_lookup(port_med_pow_devicetype_map,
 		    port->p_med_power.devicetype);
 	case lldpctl_k_med_power_source:
-		return map_lookup(port_med_pow_source_map,
-		    port->p_med_power.source);
+		return map_lookup(port_med_pow_source_map, port->p_med_power.source);
 	case lldpctl_k_med_power_priority:
 		return map_lookup(port_med_pow_priority_map.map,
 		    port->p_med_power.priority);
@@ -950,7 +954,7 @@ _lldpctl_atom_get_int_med_power(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
 	struct _lldpctl_atom_med_power_t *dpow =
 	    (struct _lldpctl_atom_med_power_t *)atom;
-	struct lldpd_port     *port     = dpow->parent->port;
+	struct lldpd_port *port = dpow->parent->port;
 
 	/* Local and remote port */
 	switch (key) {
@@ -967,9 +971,8 @@ _lldpctl_atom_get_int_med_power(lldpctl_atom_t *atom, lldpctl_key_t key)
 	}
 }
 
-static lldpctl_atom_t*
-_lldpctl_atom_set_int_med_power(lldpctl_atom_t *atom, lldpctl_key_t key,
-    long int value)
+static lldpctl_atom_t *
+_lldpctl_atom_set_int_med_power(lldpctl_atom_t *atom, lldpctl_key_t key, long int value)
 {
 	struct _lldpctl_atom_med_power_t *dpow =
 	    (struct _lldpctl_atom_med_power_t *)atom;
@@ -989,7 +992,8 @@ _lldpctl_atom_set_int_med_power(lldpctl_atom_t *atom, lldpctl_key_t key,
 		case LLDP_MED_POW_TYPE_PD:
 			port->p_med_power.devicetype = value;
 			return atom;
-		default: goto bad;
+		default:
+			goto bad;
 		}
 	case lldpctl_k_med_power_source:
 		switch (value) {
@@ -1009,7 +1013,8 @@ _lldpctl_atom_set_int_med_power(lldpctl_atom_t *atom, lldpctl_key_t key,
 		case LLDP_MED_POW_SOURCE_UNKNOWN:
 			port->p_med_power.source = value;
 			return atom;
-		default: goto bad;
+		default:
+			goto bad;
 		}
 	case lldpctl_k_med_power_priority:
 		if (value < 0 || value > 3) goto bad;
@@ -1030,7 +1035,7 @@ bad:
 	return NULL;
 }
 
-static lldpctl_atom_t*
+static lldpctl_atom_t *
 _lldpctl_atom_set_str_med_power(lldpctl_atom_t *atom, lldpctl_key_t key,
     const char *value)
 {
@@ -1050,76 +1055,69 @@ _lldpctl_atom_set_str_med_power(lldpctl_atom_t *atom, lldpctl_key_t key,
 	}
 }
 
-static struct atom_builder med_policies_list =
-	{ atom_med_policies_list, sizeof(struct _lldpctl_atom_any_list_t),
-	  .init = _lldpctl_atom_new_any_list,
-	  .free = _lldpctl_atom_free_any_list,
-	  .iter = _lldpctl_atom_iter_med_policies_list,
-	  .next = _lldpctl_atom_next_med_policies_list,
-	  .value = _lldpctl_atom_value_med_policies_list };
+static struct atom_builder med_policies_list = { atom_med_policies_list,
+	sizeof(struct _lldpctl_atom_any_list_t), .init = _lldpctl_atom_new_any_list,
+	.free = _lldpctl_atom_free_any_list,
+	.iter = _lldpctl_atom_iter_med_policies_list,
+	.next = _lldpctl_atom_next_med_policies_list,
+	.value = _lldpctl_atom_value_med_policies_list };
 
-static struct atom_builder med_policy =
-	{ atom_med_policy, sizeof(struct _lldpctl_atom_med_policy_t),
-	  .init = _lldpctl_atom_new_med_policy,
-	  .free = _lldpctl_atom_free_med_policy,
-	  .get_int = _lldpctl_atom_get_int_med_policy,
-	  .set_int = _lldpctl_atom_set_int_med_policy,
-	  .get_str = _lldpctl_atom_get_str_med_policy,
-	  .set_str = _lldpctl_atom_set_str_med_policy };
+static struct atom_builder med_policy = { atom_med_policy,
+	sizeof(struct _lldpctl_atom_med_policy_t), .init = _lldpctl_atom_new_med_policy,
+	.free = _lldpctl_atom_free_med_policy,
+	.get_int = _lldpctl_atom_get_int_med_policy,
+	.set_int = _lldpctl_atom_set_int_med_policy,
+	.get_str = _lldpctl_atom_get_str_med_policy,
+	.set_str = _lldpctl_atom_set_str_med_policy };
 
-static struct atom_builder med_locations_list =
-	{ atom_med_locations_list, sizeof(struct _lldpctl_atom_any_list_t),
-	  .init = _lldpctl_atom_new_any_list,
-	  .free = _lldpctl_atom_free_any_list,
-	  .iter = _lldpctl_atom_iter_med_locations_list,
-	  .next = _lldpctl_atom_next_med_locations_list,
-	  .value = _lldpctl_atom_value_med_locations_list };
+static struct atom_builder med_locations_list = { atom_med_locations_list,
+	sizeof(struct _lldpctl_atom_any_list_t), .init = _lldpctl_atom_new_any_list,
+	.free = _lldpctl_atom_free_any_list,
+	.iter = _lldpctl_atom_iter_med_locations_list,
+	.next = _lldpctl_atom_next_med_locations_list,
+	.value = _lldpctl_atom_value_med_locations_list };
 
-static struct atom_builder med_location =
-	{ atom_med_location, sizeof(struct _lldpctl_atom_med_location_t),
-	  .init = _lldpctl_atom_new_med_location,
-	  .free = _lldpctl_atom_free_med_location,
-	  .get     = _lldpctl_atom_get_atom_med_location,
-	  .set     = _lldpctl_atom_set_atom_med_location,
-	  .get_int = _lldpctl_atom_get_int_med_location,
-	  .set_int = _lldpctl_atom_set_int_med_location,
-	  .get_str = _lldpctl_atom_get_str_med_location,
-	  .set_str = _lldpctl_atom_set_str_med_location };
+static struct atom_builder med_location = { atom_med_location,
+	sizeof(struct _lldpctl_atom_med_location_t),
+	.init = _lldpctl_atom_new_med_location, .free = _lldpctl_atom_free_med_location,
+	.get = _lldpctl_atom_get_atom_med_location,
+	.set = _lldpctl_atom_set_atom_med_location,
+	.get_int = _lldpctl_atom_get_int_med_location,
+	.set_int = _lldpctl_atom_set_int_med_location,
+	.get_str = _lldpctl_atom_get_str_med_location,
+	.set_str = _lldpctl_atom_set_str_med_location };
 
-static struct atom_builder med_caelements_list =
-	{ atom_med_caelements_list, sizeof(struct _lldpctl_atom_med_caelements_list_t),
-	  .init = _lldpctl_atom_new_any_list,
-	  .free = _lldpctl_atom_free_any_list,
-	  .iter = _lldpctl_atom_iter_med_caelements_list,
-	  .next = _lldpctl_atom_next_med_caelements_list,
-	  .value = _lldpctl_atom_value_med_caelements_list,
-	  .create = _lldpctl_atom_create_med_caelements_list };
+static struct atom_builder med_caelements_list = { atom_med_caelements_list,
+	sizeof(struct _lldpctl_atom_med_caelements_list_t),
+	.init = _lldpctl_atom_new_any_list, .free = _lldpctl_atom_free_any_list,
+	.iter = _lldpctl_atom_iter_med_caelements_list,
+	.next = _lldpctl_atom_next_med_caelements_list,
+	.value = _lldpctl_atom_value_med_caelements_list,
+	.create = _lldpctl_atom_create_med_caelements_list };
 
-static struct atom_builder med_caelement =
-	{ atom_med_caelement, sizeof(struct _lldpctl_atom_med_caelement_t),
-	  .init = _lldpctl_atom_new_med_caelement,
-	  .free = _lldpctl_atom_free_med_caelement,
-	  .get_int = _lldpctl_atom_get_int_med_caelement,
-	  .set_int = _lldpctl_atom_set_int_med_caelement,
-	  .get_str = _lldpctl_atom_get_str_med_caelement,
-	  .set_str = _lldpctl_atom_set_str_med_caelement };
+static struct atom_builder med_caelement = { atom_med_caelement,
+	sizeof(struct _lldpctl_atom_med_caelement_t),
+	.init = _lldpctl_atom_new_med_caelement,
+	.free = _lldpctl_atom_free_med_caelement,
+	.get_int = _lldpctl_atom_get_int_med_caelement,
+	.set_int = _lldpctl_atom_set_int_med_caelement,
+	.get_str = _lldpctl_atom_get_str_med_caelement,
+	.set_str = _lldpctl_atom_set_str_med_caelement };
 
-static struct atom_builder med_power =
-	{ atom_med_power, sizeof(struct _lldpctl_atom_med_power_t),
-	  .init = _lldpctl_atom_new_med_power,
-	  .free = _lldpctl_atom_free_med_power,
-	  .get_int = _lldpctl_atom_get_int_med_power,
-	  .set_int = _lldpctl_atom_set_int_med_power,
-	  .get_str = _lldpctl_atom_get_str_med_power,
-	  .set_str = _lldpctl_atom_set_str_med_power };
+static struct atom_builder med_power = { atom_med_power,
+	sizeof(struct _lldpctl_atom_med_power_t), .init = _lldpctl_atom_new_med_power,
+	.free = _lldpctl_atom_free_med_power,
+	.get_int = _lldpctl_atom_get_int_med_power,
+	.set_int = _lldpctl_atom_set_int_med_power,
+	.get_str = _lldpctl_atom_get_str_med_power,
+	.set_str = _lldpctl_atom_set_str_med_power };
 
-ATOM_BUILDER_REGISTER(med_policies_list,   15);
-ATOM_BUILDER_REGISTER(med_policy,          16);
-ATOM_BUILDER_REGISTER(med_locations_list,  17);
-ATOM_BUILDER_REGISTER(med_location,        18);
+ATOM_BUILDER_REGISTER(med_policies_list, 15);
+ATOM_BUILDER_REGISTER(med_policy, 16);
+ATOM_BUILDER_REGISTER(med_locations_list, 17);
+ATOM_BUILDER_REGISTER(med_location, 18);
 ATOM_BUILDER_REGISTER(med_caelements_list, 19);
-ATOM_BUILDER_REGISTER(med_caelement,       20);
-ATOM_BUILDER_REGISTER(med_power,           21);
+ATOM_BUILDER_REGISTER(med_caelement, 20);
+ATOM_BUILDER_REGISTER(med_power, 21);
 
 #endif
-
